#!/bin/bash

# Buildscript for Lbreakout2 by Paulo Costa - pamgcosta AT sapo DOT net
# Last modified on 7 February 2007
# Homepage & source location: http://lgames.sourceforge.net/index.php?project=LBreakout2

# Set variables
builddir=$(pwd)
soft="lbreakout2"
ver="2.6b7"
srcpak="$soft-2.6beta-7.tar.gz"
srcdir="$builddir/$soft-2.6beta-7"
zv="44"
build="4"
arch="i686"
pakdir="$builddir/$soft-$ver-$arch-$zv.$build"
pak="$soft-$ver-$arch-$zv.$build"
CFLAGS="-O2 -march=$arch -mtune=i686"

# Cleanup the build area
rm -rf $srcdir
rm -rf $pakdir
rm -rf $pak.*

# Explode the source tarball
tar -xzvf $srcpak

# Run the configure script with the needed options and make
# 'localstatedir' determines where the highscore file will be created
# and nothing else, hence the non-standard path
export CFLAGS
cd $srcdir
./configure --prefix=/usr \
	--with-doc-dir=/usr/doc/lbreakout-2.6b7 \
	--localstatedir=/usr/share/lbreakout-2.6b7 \
	--sysconfdir=/etc
make

# Create the package directory and install the built files there
mkdir -p $pakdir
make DESTDIR="$pakdir" install

# Strip binaries
cd $pakdir
(find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded)

# Compress man pages in case there are any
if [ -d $pakdir/man ]; then
	find $pakdir/man -type f -exec gzip {} \;
fi

# Create and populate the doc directory
cd $srcdir
mkdir -p $pakdir/usr/doc/$soft-$ver
cp -a ABOUT-NLS AUTHORS COPYING ChangeLog INSTALL NEWS README README-SDL.txt TODO $pakdir/usr/doc/$soft-$ver

# Move user manual to the docs directory
mv $pakdir/usr/doc/$soft $pakdir/usr/doc/$soft-$ver

# Create the slack-desc file
cd $builddir
mkdir -p $pakdir/install
cat <<EOF> $pakdir/install/slack-desc
|------------------------------------------------------------------------------|
$soft: LBreakout2 is an open-source Breakout clone
$soft: 
$soft: LBreakout2 is a sequel to LBreakout, featuring new levels,
$soft: power-ups and bonuses. Control your pad and deflect the ball
$soft: to hit and destroy. all the bricks on the screen. Some of 
$soft: those bricks will release power-ups and bonus items when hit.
$soft: 
$soft: 
$soft:
$soft: 
$soft:
$soft:
$soft:
EOF

# Create the desktop entry
mkdir -p $pakdir/usr/share/applications
cat <<EOF> $pakdir/usr/share/applications/$soft.desktop
[Desktop Entry]
Encoding=UTF-8
Name=LBreakout2
Comment=Action
Exec=lbreakout2
Terminal=false
Type=Application
Categories=Game;Action;
Icon=lbreakout2
EOF

# Copy icon into package, if there's one
if [ -f $soft.png ]; then
	mkdir -p $pakdir/usr/share/icons/hicolor/48x48/apps
	cp -a $soft.png $pakdir/usr/share/icons/hicolor/48x48/apps
fi

# Store the buildscript in the package too
mkdir -p $pakdir/usr/src/$soft-$ver
cp -a $builddir/build-$soft.sh $pakdir/usr/src/$soft-$ver

# Create the dep file
rm -f $builddir/$pak.dep
cd $pakdir
requiredbuilder -z $pakdir >$builddir/$pak.dep

# Set owner of the entire package tree to root
chown -R root:root $pakdir

# Set permissions of document files and dirs
chmod -R 544 $pakdir/usr/doc/$soft-$ver/*
find $pakdir/usr/doc/$soft-$ver -type d -exec chmod 755 {} \;

# Create package
cd $pakdir
makepkg -l y -c n $pak.tgz
mv $pak.tgz ../$pak.tgz

# Create MD5 checksum
cd $builddir
md5sum $pak.tgz > $pak.md5

# Cleanup
rm -rf $srcdir
rm -rf $pakdir
